"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamoDb = void 0;
const Errors_1 = require("../Errors");
const Lambda_1 = require("../Lambda");
const aws_sdk_1 = require("aws-sdk");
class DynamoDb {
    constructor({ accessKeyId, endpoint, region, secretAccessKey }) {
        const credentials = accessKeyId && secretAccessKey ? new aws_sdk_1.Credentials({ accessKeyId, secretAccessKey }) : undefined;
        this.documentClient = new aws_sdk_1.DynamoDB.DocumentClient({ endpoint, region, credentials });
        const table = Lambda_1.getEnvConfig('DATASOURCE_TABLE_NAME');
        if (!table)
            throw new Errors_1.InternalServerError('Environment variable DATASOURCE_TABLE_NAME not found');
        this.tableName = table;
    }
    async get(Key) {
        const { Item } = await this.documentClient.get({ TableName: this.tableName, Key }).promise();
        return Item;
    }
    async put(Item) {
        await this.documentClient.put({ TableName: this.tableName, Item }).promise();
    }
    async delete(Key) {
        await this.documentClient.delete({ TableName: this.tableName, Key }).promise();
    }
    async update(Key, updateData) {
        return await this.documentClient
            .update({
            TableName: this.tableName,
            Key,
            ...updateData,
        })
            .promise();
    }
}
exports.DynamoDb = DynamoDb;
