import { APIGatewayProxyEvent, Context } from 'aws-lambda';
export interface RouterInterface {
    addRoute: (routes: RouteInterface[]) => void;
    route: (request: APIGatewayProxyEvent, context: Context) => Promise<Response>;
}
export interface RouteInterface {
    path: string;
    get?: RouteHandler;
    post?: RouteHandler;
    put?: RouteHandler;
    delete?: RouteHandler;
}
export interface Response {
    isOk: boolean;
    endpoint: string;
    uri: string;
    response: {
        statusCode: number;
        body: string;
        headers: Record<string, string>;
    };
}
export declare type RouteHandler = (event: Event, context: RouterContext) => Promise<HttpResponse>;
export interface Event {
    headers: Record<string, string>;
    queryStringParameters: Record<string, string>;
    multiValueQueryStringParameters: Record<string, string[]> | null;
    pathParameters: Record<string, string>;
    rawBody: string | null;
    isBase64Encoded: boolean;
}
export interface HttpResponse {
    statusCode: number;
    body: any;
    headers?: Record<string, string>;
}
export interface RouterContext extends Context {
    response: RouterResponseBuilder;
}
declare type RouterResponseBuilder = (statusCode: number, body: any, headers?: Record<string, string>) => Promise<any>;
export {};
